# sgeom - Scattering Geometry

This is a package to handle scattering geometry. It can:
- Create a scattering geometry with arbitrary detector, beam and sample geometry.
- Calculate reciprocal space coordinates.

Examples:
- A quick start jupyter notebook is at: [examples/usage.ipynb](examples/with_extra-geom.ipynb).
- An example using geom from extra-geom is at: [examples/with_extra-geom.ipynb](examples/with_extra-geom.ipynb).
